parse_all_packs

Function parse_all_packs 

pub fn parse_all_packs(b: &[u8]) -> Result<(Vec<Pack<'_>>, &[u8])>
Iterate over all packs in a Program Stream buffer.

Returns all packs and the remaining trailing bytes (if any).