PackHeader

Struct PackHeader 

pub struct PackHeader<'a> {
    pub scr: Scr,
    pub program_mux_rate: u32,
    pub stuffing_length: u8,
    pub stuffing: &'a [u8],
    pub reserved: u8,
}
A parsed pack header.

Fields

scr: Scr

System Clock Reference (42-bit; 33-bit base + 9-bit extension, 27 MHz).

program_mux_rate: u32

Rate at which the P-STD receives the stream during this pack, in units of 50 bytes/s. Must be non-zero.

stuffing_length: u8

The pack_stuffing_length field value (≤ 7).

stuffing: &'a [u8]

Stuffing bytes (0xFF), zero to seven bytes.

reserved: u8

Reserved bits (5 bits, preserved for round-trip).

Implementations

Source

impl PackHeader<'_>

pub fn header_len(&self) -> usize

Offset to the byte immediately after this pack header (i.e. where PES data starts).